## UEngine

UEngine is a python micro-framework based on Flask and Pymongo. It is used by a number of open-source projects like [inventoree.ru](https://c.inventoree.ru), [Atushka](https://atushka.ru) as well as by some in-house proprietary internal projects at leading russian IT companies.

This repository aim is to separate uengine code from mentioned above projects' codebase to make it easier to synchronize framework version and add more DRY (don't-repeat-yourself) approach to them.

This is a deep-work-in-progress-thing. Use it at your own risk.
